@@ -14,15 +14,15 @@ import (
 	C "github.com/metacubex/mihomo/constant"
 	"github.com/metacubex/mihomo/log"
 
+	mux "github.com/metacubex/sing-mux"
 	vmess "github.com/metacubex/sing-vmess"
-	mux "github.com/sagernet/sing-mux"
-	"github.com/sagernet/sing/common/buf"
-	"github.com/sagernet/sing/common/bufio"
-	"github.com/sagernet/sing/common/bufio/deadline"
-	E "github.com/sagernet/sing/common/exceptions"
-	M "github.com/sagernet/sing/common/metadata"
-	"github.com/sagernet/sing/common/network"
-	"github.com/sagernet/sing/common/uot"
+	"github.com/metacubex/sing/common/buf"
+	"github.com/metacubex/sing/common/bufio"
+	"github.com/metacubex/sing/common/bufio/deadline"
+	E "github.com/metacubex/sing/common/exceptions"
+	M "github.com/metacubex/sing/common/metadata"
+	"github.com/metacubex/sing/common/network"
+	"github.com/metacubex/sing/common/uot"
 )
 
 const UDPTimeout = 5 * time.Minute
